#include <iostream>

#include "scene.h"

using namespace std;

Scene::Scene()
{
    setSceneRect(0, 0, WIDTH, HEIGHT);
    
    stepTimer.setInterval(UPDATE_INTERVAL);
    connect(&stepTimer, SIGNAL(timeout()), SLOT(step()));
    stepTimer.start();
}

void Scene::step()
{
    foreach (Ball *ball, balls) {
        ball->moveBy(ball->directionX, ball->directionY);
        
        QRectF rect = ball->sceneBoundingRect();
        
        // bounce against the wall
        if (rect.left() < 0 && ball->directionX < 0)
            ball->directionX *= -1;
        else if (rect.right() > WIDTH && ball->directionX > 0)
            ball->directionX *= -1;
        else if (rect.top() < 0 && ball->directionY < 0)
            ball->directionY *= -1;
        else if (rect.bottom() > HEIGHT && ball->directionY > 0)
            ball->directionY *= -1;
    }
}

void Scene::mousePressEvent(QGraphicsSceneMouseEvent *event)
{
    qreal x = event->lastScenePos().x();
    qreal y = event->lastScenePos().y();
    Ball *ball = new Ball(QRectF(x, y, BALL_SIZE, BALL_SIZE));
    ball->directionX = 3;
    ball->directionY = 5;
    ball->setPen(Qt::NoPen);
    ball->setBrush(Qt::black);
    addItem(ball);
    balls.append(ball);
    
    QGraphicsScene::mousePressEvent(event);
}
